pub struct CobylaState {Show 20 fields
pub param: Option<Vec<f64>>,
pub prev_param: Option<Vec<f64>>,
pub best_param: Option<Vec<f64>>,
pub prev_best_param: Option<Vec<f64>>,
pub cost: Option<Vec<f64>>,
pub prev_cost: Option<Vec<f64>>,
pub best_cost: Option<Vec<f64>>,
pub prev_best_cost: Option<Vec<f64>>,
pub target_cost: f64,
pub iter: u64,
pub last_best_iter: u64,
pub max_iters: u64,
pub counts: HashMap<String, u64>,
pub time: Option<Duration>,
pub termination_status: TerminationStatus,
pub rhobeg: f64,
pub rhoend: f64,
pub iprint: i32,
pub maxfun: i32,
pub cobyla_context: Option<ManuallyDrop<*mut _cobyla_context>>,
}Expand description
Maintains the state from iteration to iteration of the crate::CobylaSolver.
This struct is passed from one iteration of an algorithm to the next.
Keeps track of
- parameter vector of current and previous iteration
- best parameter vector of current and previous iteration
- cost function value (objective and constraint functions values) of current and previous iteration
- current and previous best cost function value
- target cost function value
- current iteration number
- iteration number where the last best parameter vector was found
- maximum number of iterations that will be executed
- problem function evaluation counts
- elapsed time
- termination status
- COBYLA specific parameters: rhobeg, rhoend, iprint, maxfun
Fields
param: Option<Vec<f64>>Current parameter vector
prev_param: Option<Vec<f64>>Previous parameter vector
best_param: Option<Vec<f64>>Current best parameter vector
prev_best_param: Option<Vec<f64>>Previous best parameter vector
cost: Option<Vec<f64>>Current cost function value
prev_cost: Option<Vec<f64>>Previous cost function value
best_cost: Option<Vec<f64>>Current best cost function value
prev_best_cost: Option<Vec<f64>>Previous best cost function value
target_cost: f64Target cost function value
iter: u64Current iteration
last_best_iter: u64Iteration number of last best cost
max_iters: u64Maximum number of iterations
counts: HashMap<String, u64>Evaluation counts
time: Option<Duration>Time required so far
termination_status: TerminationStatusStatus of optimization execution
rhobeg: f64Rho start value
rhoend: f64Rho end value
iprint: i32Control of traces
maxfun: i32Cost function calls budget
cobyla_context: Option<ManuallyDrop<*mut _cobyla_context>>Implementations
Sourceimpl CobylaState
impl CobylaState
Sourcepub fn param(self, param: Vec<f64>) -> Self
pub fn param(self, param: Vec<f64>) -> Self
Set parameter vector. This shifts the stored parameter vector to the previous parameter vector.
Example
let state = state.param(param);Sourcepub fn target_cost(self, target_cost: f64) -> Self
pub fn target_cost(self, target_cost: f64) -> Self
Set target cost.
When this cost is reached, the algorithm will stop. The default is
Self::Float::NEG_INFINITY.
Example
let state = state.target_cost(0.0);Sourcepub fn cost(self, cost: Vec<f64>) -> Self
pub fn cost(self, cost: Vec<f64>) -> Self
Set the current cost function value. This shifts the stored cost function value to the previous cost function value.
Example
let state = state.cost(vec![cost]);Sourcepub fn get_full_cost(&self) -> Option<&Vec<f64>>
pub fn get_full_cost(&self) -> Option<&Vec<f64>>
Returns current cost (ie objective) function and constraint values.
Example
let cost = state.get_full_cost();Sourcepub fn get_full_best_cost(&self) -> Option<&Vec<f64>>
pub fn get_full_best_cost(&self) -> Option<&Vec<f64>>
Returns current cost (ie objective) function and constraint values.
Example
let cost = state.get_full_best_cost();Sourcepub fn get_rhoend(&self) -> f64
pub fn get_rhoend(&self) -> f64
Returns the rho end value
Sourcepub fn get_iprint(&self) -> i32
pub fn get_iprint(&self) -> i32
Returns the level of printing
Sourcepub fn get_maxfun(&self) -> i32
pub fn get_maxfun(&self) -> i32
Returns cost function calls budget